.. later documentation master file, created by
   sphinx-quickstart on Thu Feb  6 18:29:36 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to later's documentation!
=================================


later is a play on Async not happening now but at some point in the future.
It was also an awsome name for a toolkit for writing AsyncIO applications. The
*batteries* if you will for AsyncIO.

Contents:


.. toctree::
   :maxdepth: 3
   :caption: Contents:

   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
